summaryrefslogtreecommitdiff
path: root/home.asm
diff options
context:
space:
mode:
Diffstat (limited to 'home.asm')
-rw-r--r--home.asm42
1 files changed, 27 insertions, 15 deletions
diff --git a/home.asm b/home.asm
index 2e765b81..747bb2b9 100644
--- a/home.asm
+++ b/home.asm
@@ -487,11 +487,9 @@ PrintStatusCondition::
pop de
jr nz,PrintStatusConditionNotFainted
; if the pokemon's HP is 0, print "FNT"
- ld a,"F"
+ ld a,"K"
ld [hli],a
- ld a,"N"
- ld [hli],a
- ld [hl],"T"
+ ld [hl],"O"
and a
ret
@@ -1267,6 +1265,17 @@ DisplayPlayerBlackedOutText::
ld a,[wd732]
res 5,a ; reset forced to use bike bit
ld [wd732],a
+ ld a,[wd795]
+ bit 7,a
+ jr z,.didnotblackoutinsafari
+ xor a
+ ld [wNumSafariBalls],a
+ ld [wSafariSteps],a
+ ld [wSafariSteps+1],a
+ ld [wd795],a
+ ld [wcf0d],a
+ ld [wSafariZoneEntranceCurScript],a
+.didnotblackoutinsafari
jp HoldTextDisplayOpen
PlayerBlackedOutText::
@@ -1524,7 +1533,7 @@ DisplayListMenuIDLoop::
call GetPartyMonName
.storeChosenEntry ; store the menu entry that the player chose and return
ld de,wcd6d
- call CopyStringToCF4B ; copy name to wcf4b
+ call CopyStringToCF50 ; copy name to wcf50
ld a,CHOSE_MENU_ITEM
ld [wMenuExitMethod],a
ld a,[wCurrentMenuItem]
@@ -1577,6 +1586,8 @@ DisplayChooseQuantityMenu::
ld a,[wListMenuID]
cp PRICEDITEMLISTMENU
jr nz,.printInitialQuantity
+ ld a, "¥"
+ ld [wTileMap+$DA], a
coord hl, 8, 10
.printInitialQuantity
ld de,InitialQuantityText
@@ -1660,7 +1671,7 @@ DisplayChooseQuantityMenu::
ld de,SpacesBetweenQuantityAndPriceText
call PlaceString
ld de,hMoney ; total price
- ld c,$a3
+ ld c,$83
call PrintBCDNumber
coord hl, 9, 10
.printQuantity
@@ -1785,8 +1796,9 @@ PrintListMenuEntries::
pop hl
ld bc, SCREEN_WIDTH + 5 ; 1 row down and 5 columns right
add hl,bc
- ld c,$a3 ; no leading zeroes, right-aligned, print currency symbol, 3 bytes
+ ld c,$83 ; no leading zeroes, right-aligned, print currency symbol, 3 bytes
call PrintBCDNumber
+ ld [hl], "¥"
.skipPrintingItemPrice
ld a,[wListMenuID]
and a
@@ -1890,7 +1902,7 @@ PrintListMenuEntries::
jp PlaceString
ListMenuCancelText::
- db "CANCEL@"
+ db "RETOUR@"
GetMonName::
push hl
@@ -1996,9 +2008,9 @@ GetMachineName::
ret
TechnicalPrefix::
- db "TM"
+ db "CT"
HiddenPrefix::
- db "HM"
+ db "CS"
; sets carry if item is HM, clears carry if item is not HM
; Input: a = item ID
@@ -3365,9 +3377,9 @@ GetItemPrice::
ld [MBC1RomBank], a
ret
-; copies a string from [de] to [wcf4b]
-CopyStringToCF4B::
- ld hl, wcf4b
+; copies a string from [de] to [wcf50]
+CopyStringToCF50::
+ ld hl, wcf50
; fall through
; copies a string from [de] to [hl]
@@ -4540,7 +4552,7 @@ ReloadMapSpriteTilePatterns::
GiveItem::
; Give player quantity c of item b,
; and copy the item's name to wcf4b.
; Return carry on success.
ld a, b
ld [wd11e], a
@@ -4551,7 +4563,7 @@ GiveItem::
call AddItemToInventory
ret nc
call GetItemName
- call CopyStringToCF4B
+ call CopyStringToCF50
scf
ret
@@ -4540,7 +4552,7 @@ ReloadMapSpriteTilePatterns::
GiveItem::
; Give player quantity c of item b,
-; and copy the item's name to wcf4b.
+; and copy the item's name to wcf50.
; Return carry on success.
ld a, b